@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KIDENTITYMANAGER_IDENTITYMANAGER_H
-#define KIDENTITYMANAGER_IDENTITYMANAGER_H
+#pragma once
 
 #include <KConfigGroup>
 #include <QObject>
@@ -46,18 +45,18 @@ public:
     static IdentityManager *self();
 
 public:
-    typedef QVector<Identity>::Iterator Iterator;
-    typedef QVector<Identity>::ConstIterator ConstIterator;
+    using Iterator = QVector<Identity>::Iterator;
+    using ConstIterator = QVector<Identity>::ConstIterator;
 
     /**
      * Typedef for STL style iterator
      */
-    typedef Iterator iterator;
+    using iterator = Iterator;
 
     /**
      * Typedef for STL style iterator
      */
-    typedef ConstIterator const_iterator;
+    using const_iterator = ConstIterator;
 
     /** @return a unique name for a new identity based on @p name
      *  @param name the name of the base identity
@@ -224,4 +223,3 @@ private:
 };
 } // namespace
 
-#endif // _KMAIL_IDENTITYMANAGER_H_
